% Auto-generated chapter 35 for abudawud
% Hadiths in this chapter: 55

\hadithdefcmd{abudawud}{4159}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّرَجُّلِ إِلاَّ غِبًّا ‏.‏\hadithno{4159}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mughaffal: The Messenger of Allah (ﷺ) forbade combing the hair except every second day}}
\hadithdefcmd{abudawud}{4160}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ الْمَازِنِيُّ، أَخْبَرَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم رَحَلَ إِلَى فَضَالَةَ بْنِ عُبَيْدٍ وَهُوَ بِمِصْرَ فَقَدِمَ عَلَيْهِ فَقَالَ أَمَا إِنِّي لَمْ آتِكَ زَائِرًا وَلَكِنِّي سَمِعْتُ أَنَا وَأَنْتَ حَدِيثًا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم رَجَوْتُ أَنْ يَكُونَ عِنْدَكَ مِنْهُ عِلْمٌ ‏.‏ قَالَ وَمَا هُوَ قَالَ كَذَا وَكَذَا قَالَ فَمَا لِي أَرَاكَ شَعِثًا وَأَنْتَ أَمِيرُ الأَرْضِ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَنْهَانَا عَنْ كَثِيرٍ مِنَ الإِرْفَاهِ ‏.‏ قَالَ فَمَا لِي لاَ أَرَى عَلَيْكَ حِذَاءً قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْمُرُنَا أَنْ نَحْتَفِيَ أَحْيَانًا ‏.‏\hadithno{4160}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah ibn Buraydah said:A man from the companions of the Prophet (ﷺ) travelled to Fudalah ibn Ubayd when he was in Egypt. He came to him and said: I have not come to you to visit you. But you and I heard a tradition from the Messenger of Allah (ﷺ). I hope you may have some knowledge of it. He asked: What is it? He replied: So and so. He said: Why do I see you dishevelled when you are the ruler of this land? He said: The Messenger of Allah (ﷺ) has forbidden us to indulge much in luxury. He said: Why do I see you unshod? He replied: The Prophet (ﷺ) used to command us to go barefoot at times}}
\hadithdefcmd{abudawud}{4161}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أُمَامَةَ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي أُمَامَةَ، قَالَ ذَكَرَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمًا عِنْدَهُ الدُّنْيَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ تَسْمَعُونَ أَلاَ تَسْمَعُونَ إِنَّ الْبَذَاذَةَ مِنَ الإِيمَانِ إِنَّ الْبَذَاذَةَ مِنَ الإِيمَانِ ‏"‏ ‏.‏ يَعْنِي التَّقَحُّلَ ‏.‏ قَالَ أَبُو دَاوُدَ هُوَ أَبُو أُمَامَةَ بْنُ ثَعْلَبَةَ الأَنْصَارِيُّ ‏.‏\hadithno{4161}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUmamah Ilyas ibn Tha'labah: The Companions of the Messenger of Allah (ﷺ) mentioned this word before him. The Messenger of Allah (ﷺ) said: Listen, listen! Wearing old clothes is a part of faith, wearing old clothes is a part of faith. Abu Dawud said: He is Abu Umamah b. Tha'labat al-Ansari}}
\hadithdefcmd{abudawud}{4162}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ، عَنْ شَيْبَانَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُخْتَارِ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَتْ لِلنَّبِيِّ صلى الله عليه وسلم سُكَّةٌ يَتَطَيَّبُ مِنْهَا ‏.‏\hadithno{4162}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) had sikkah with which he perfumed himself}}
\hadithdefcmd{abudawud}{4163}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي ابْنُ أَبِي الزِّنَادِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ لَهُ شَعْرٌ فَلْيُكْرِمْهُ ‏"‏ ‏.‏\hadithno{4163}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: He who has hair should honour it}}
\hadithdefcmd{abudawud}{4164}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَتْنِي كَرِيمَةُ بِنْتُ هَمَّامٍ، أَنَّ امْرَأَةً، أَتَتْ عَائِشَةَ - رضى الله عنها - فَسَأَلَتْهَا عَنْ خِضَابِ الْحِنَّاءِ فَقَالَتْ لاَ بَأْسَ بِهِ وَلَكِنِّي أَكْرَهُهُ كَانَ حَبِيبِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَكْرَهُ رِيحَهُ ‏.‏ قَالَ أَبُو دَاوُدَ تَعْنِي خِضَابَ شَعْرِ الرَّأْسِ ‏.‏\hadithno{4164}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Karimah, daughter of Hammam, told that a woman came to Aisha (Allah be pleased with her) and asked her about dyeing with henna. She replied: There is no harm, but I do not like it. My beloved, the Messenger of Allah (ﷺ), disliked its odour. Abu Dawud said: She meant the colour of hair of the head}}
\hadithdefcmd{abudawud}{4165}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَتْنِي غِبْطَةُ بِنْتُ عَمْرٍو الْمُجَاشِعِيَّةُ، قَالَتْ حَدَّثَتْنِي عَمَّتِي أُمُّ الْحَسَنِ، عَنْ جَدَّتِهَا، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ هِنْدًا بِنْتَ عُتْبَةَ، قَالَتْ يَا نَبِيَّ اللَّهِ بَايِعْنِي ‏.‏ قَالَ ‏ "‏ لاَ أُبَايِعُكِ حَتَّى تُغَيِّرِي كَفَّيْكِ كَأَنَّهُمَا كَفَّا سَبُعٍ ‏"‏ ‏.‏\hadithno{4165}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When Hind, daughter of Utbah, said: Prophet of Allah, accept my allegiance, he replied; I shall not accept your allegiance till you make a difference to the palms of your hands; for they look like the paws of a beast of prey}}
\hadithdefcmd{abudawud}{4166}{حَدَّثَنَا مُحَمَّدُ بْنُ مُحَمَّدٍ الصُّورِيُّ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا مُطِيعُ بْنُ مَيْمُونٍ، عَنْ صَفِيَّةَ بِنْتِ عِصْمَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ أَوْمَتِ امْرَأَةٌ مِنْ وَرَاءِ سِتْرٍ بِيَدِهَا كِتَابٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَبَضَ النَّبِيُّ صلى الله عليه وسلم يَدَهُ فَقَالَ ‏"‏ مَا أَدْرِي أَيَدُ رَجُلٍ أَمْ يَدُ امْرَأَةٍ ‏"‏ ‏.‏ قَالَتْ بَلِ امْرَأَةٌ ‏.‏ قَالَ ‏"‏ لَوْ كُنْتِ امْرَأَةً لَغَيَّرْتِ أَظْفَارَكِ ‏"‏ ‏.‏ يَعْنِي بِالْحِنَّاءِ ‏.‏\hadithno{4166}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A woman made a sign from behind a curtain to indicate that she had a letter for the Messenger of Allah (ﷺ). The Prophet (ﷺ) closed his hand, saying: I do not know this is a man's or a woman's hand. She said: No, a woman. He said: If you were a woman, you would make a difference to your nails, meaning with henna}}
\hadithdefcmd{abudawud}{4167}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، عَامَ حَجَّ وَهُوَ عَلَى الْمِنْبَرِ وَتَنَاوَلَ قُصَّةً مِنْ شَعْرٍ كَانَتْ فِي يَدِ حَرَسِيٍّ يَقُولُ يَا أَهْلَ الْمَدِينَةِ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ مِثْلِ هَذِهِ وَيَقُولُ ‏ "‏ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ اتَّخَذَ هَذِهِ نِسَاؤُهُمْ ‏"‏ ‏.‏\hadithno{4167}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3468) Sahih Muslim (2127)}\hadithtrans{Narrated Humaid b. 'Adb al-Rahman:That he heard Mu'awiyah b. Abi Sufyan say during the Hajj when he was on the pulpit and took a lock of hair which was in the hand of the guard, saying: O people of Medina, where are your scholars ? I heard the Messenger of Allah (ﷺ) forbidding such a think as this and said: The children of Isra'il perished when their women practised it}}
\hadithdefcmd{abudawud}{4168}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏.‏\hadithno{4168}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5947) Sahih Muslim (2124)}\hadithtrans{Abd Allah said:The Messenger of Allah (ﷺ) cursed the woman who adds some false hair and the woman who asks for it, the woman who tattoos and the woman who asks for it}}
\hadithdefcmd{abudawud}{4169}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَعَنَ اللَّهُ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ ‏.‏ قَالَ مُحَمَّدٌ وَالْوَاصِلاَتِ وَقَالَ عُثْمَانُ وَالْمُتَنَمِّصَاتِ ثُمَّ اتَّفَقَا وَالْمُتَفَلِّجَاتِ لِلْحُسْنِ الْمُغَيِّرَاتِ خَلْقَ اللَّهِ عَزَّ وَجَلَّ ‏.‏ فَبَلَغَ ذَلِكَ امْرَأَةً مِنْ بَنِي أَسَدٍ يُقَالُ لَهَا أُمُّ يَعْقُوبَ ‏.‏ زَادَ عُثْمَانُ كَانَتْ تَقْرَأُ الْقُرْآنَ ثُمَّ اتَّفَقَا فَأَتَتْهُ فَقَالَتْ بَلَغَنِي عَنْكَ أَنَّكَ لَعَنْتَ الْوَاشِمَاتِ وَالْمُسْتَوْشِمَاتِ ‏.‏ قَالَ مُحَمَّدٌ وَالْوَاصِلاَتِ وَقَالَ عُثْمَانُ وَالْمُتَنَمِّصَاتِ ثُمَّ اتَّفَقَا وَالْمُتَفَلِّجَاتِ قَالَ عُثْمَانُ لِلْحُسْنِ الْمُغَيِّرَاتِ خَلْقَ اللَّهِ تَعَالَى ‏.‏ فَقَالَ وَمَا لِي لاَ أَلْعَنُ مَنْ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي كِتَابِ اللَّهِ تَعَالَى قَالَتْ لَقَدْ قَرَأْتُ مَا بَيْنَ لَوْحَىِ الْمُصْحَفِ فَمَا وَجَدْتُهُ ‏.‏ فَقَالَ وَاللَّهِ لَئِنْ كُنْتِ قَرَأْتِيهِ لَقَدْ وَجَدْتِيهِ ثُمَّ قَرَأَ ‏\{‏ وَمَا آتَاكُمُ الرَّسُولُ فَخُذُوهُ وَمَا نَهَاكُمْ عَنْهُ فَانْتَهُوا ‏\}‏ قَالَتْ إِنِّي أَرَى بَعْضَ هَذَا عَلَى امْرَأَتِكَ ‏.‏ قَالَ فَادْخُلِي فَانْظُرِي ‏.‏ فَدَخَلَتْ ثُمَّ خَرَجَتْ فَقَالَ مَا رَأَيْتِ وَقَالَ عُثْمَانُ فَقَالَتْ مَا رَأَيْتُ ‏.‏ فَقَالَ لَوْ كَانَ ذَلِكَ مَا كَانَتْ مَعَنَا ‏.‏\hadithno{4169}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5931) Sahih Muslim (2125)}\hadithtrans{Abd Allah (b. Mas'us) said:Allah has cursed the woman who tattoo and the women who have themselves tattooed, the women who add false hair (according to the version of Muhammad b. Isa) and the women who pluck hairs from their faces (according to the version on 'Uthman). The agreed version then goes: The women who spaces between their teeth for beauty, changing what Allah has created. When a woman of Banu Asad called Umm Ya'qub, who read the Qur'an (according to the version of 'Uthman) heard it, she came to him (according to the agreed version) and said: I have heard that you have cursed the women who tattoo, those have themselves tattooed, those who add false hair (according to the version of Muhammad), those pluck hairs from their faces, and those who make spaces between their teeth (according to the agreed version), for changing what Allah has created (according to the version of 'Uthman). He said: Why should I not curse those whom the Messenger of Allah (ﷺ) had cursed and those who were mentioned in Allah's Book ? She said: I have read it from cover to cover and have not found in it. He said: I swear by Allah, if you read it, you would have found it. He then read: What the Apostle has brought you accept, and what he has forbidden refrain from it. She said: I find some of these thing in you wife. He said: Enter (the house) and see. She said: I then entered (the house) and came out. He asked: What did you see ? She said: I did not see (anything). He said: Had it been so, she would have not have been with us. This is according to the version of 'Uthman}}
\hadithdefcmd{abudawud}{4170}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ أُسَامَةَ، عَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ مُجَاهِدِ بْنِ جَبْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لُعِنَتِ الْوَاصِلَةُ وَالْمُسْتَوْصِلَةُ وَالنَّامِصَةُ وَالْمُتَنَمِّصَةُ وَالْوَاشِمَةُ وَالْمُسْتَوْشِمَةُ مِنْ غَيْرِ دَاءٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَتَفْسِيرُ الْوَاصِلَةِ الَّتِي تَصِلُ الشَّعْرَ بِشَعْرِ النِّسَاءِ وَالْمُسْتَوْصِلَةُ الْمَعْمُولُ بِهَا وَالنَّامِصَةُ الَّتِي تَنْقُشُ الْحَاجِبَ حَتَّى تَرِقَّهُ وَالْمُتَنَمِّصَةُ الْمَعْمُولُ بِهَا وَالْوَاشِمَةُ الَّتِي تَجْعَلُ الْخِيلاَنَ فِي وَجْهِهَا بِكُحْلٍ أَوْ مِدَادٍ وَالْمُسْتَوْشِمَةُ الْمَعْمُولُ بِهَا ‏.‏\hadithno{4170}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas: The woman who supplies fake hair and the one who asks for it, the woman who pulls out hair for other people and the woman who depilates herself, the woman who tattoos and the one who has it done when there is no disease to justify it have been cursed. Abu Dawud said: Wasilah means the woman who adds false hair to the hair of women. Mustawsilah means the one who asks for adding the hair to her hair. namisah means a woman who plucks hair from the brow until she makes it thin; mutanammisah means the woman who depilates herself ; washimah is a woman who tattoos in the face with antimony or ink ; mustawshimah is a woman with whom it is done}}
\hadithdefcmd{abudawud}{4171}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ سَالِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ لاَ بَأْسَ بِالْقَرَامِلِ ‏.‏ قَالَ أَبُو دَاوُدَ كَأَنَّهُ يَذْهَبُ إِلَى أَنَّ الْمَنْهِيَّ، عَنْهُ شُعُورُ النِّسَاءِ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ أَحْمَدُ يَقُولُ الْقَرَامِلُ لَيْسَ بِهِ بَأْسٌ ‏.‏\hadithno{4171}\hadithgrade{Al-Albani: Daif Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Sa'id b. Jubair said:There is no harm in fastening the hair with silk or woollen threads. Abu Dawud said: It appears that he held the view that what is prohibited is the adding of the hair of women. Abu Dawud said: Ahmad (b. hanbal) used to say: There is no harm in tying the hair with silk or woollen threads}}
\hadithdefcmd{abudawud}{4172}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، - الْمَعْنَى - أَنَّ أَبَا عَبْدِ الرَّحْمَنِ الْمُقْرِئَ، حَدَّثَهُمْ عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عُرِضَ عَلَيْهِ طِيبٌ فَلاَ يَرُدَّهُ فَإِنَّهُ طَيِّبُ الرِّيحِ خَفِيفُ الْمَحْمَلِ ‏"‏ ‏.‏\hadithno{4172}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2253)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:If anyone is presented some perfume, he should not return it, for it is a thing of good fragrance and light to bear}}
\hadithdefcmd{abudawud}{4173}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، أَخْبَرَنَا ثَابِتُ بْنُ عُمَارَةَ، حَدَّثَنِي غُنَيْمُ بْنُ قَيْسٍ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَعْطَرَتِ الْمَرْأَةُ فَمَرَّتْ عَلَى الْقَوْمِ لِيَجِدُوا رِيحَهَا فَهِيَ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ قَوْلاً شَدِيدًا ‏.‏\hadithno{4173}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuMusa: The Prophet (ﷺ) said: If a woman uses perfume and passes the people so that they may get its odour, she is so-and-so, meaning severe remarks}}
\hadithdefcmd{abudawud}{4174}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ، مَوْلَى أَبِي رُهْمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ لَقِيَتْهُ امْرَأَةٌ وَجَدَ مِنْهَا رِيحَ الطِّيبِ يُنْفَحُ وَلِذَيْلِهَا إِعْصَارٌ فَقَالَ يَا أَمَةَ الْجَبَّارِ جِئْتِ مِنَ الْمَسْجِدِ قَالَتْ نَعَمْ ‏.‏ قَالَ وَلَهُ تَطَيَّبْتِ قَالَتْ نَعَمْ ‏.‏ قَالَ إِنِّي سَمِعْتُ حِبِّي أَبَا الْقَاسِمِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْبَلُ صَلاَةٌ لاِمْرَأَةٍ تَطَيَّبَتْ لِهَذَا الْمَسْجِدِ حَتَّى تَرْجِعَ فَتَغْتَسِلَ غُسْلَهَا مِنَ الْجَنَابَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الإِعْصَارُ غُبَارٌ ‏.‏\hadithno{4174}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: A woman met him and he found the odour of perfume in her. Her clothes were fluttering in the air. He said: O maid-servant of the Almighty, are you coming from the mosque? She replied: Yes. He said: For it did you use perfume? She replied: Yes. He said: I heard my beloved AbulQasim (ﷺ) say: The prayer of a woman who uses perfume for this mosque is not accepted until she returns and takes a bath like that of sexual defilement (perfectly). Abu Dawud said: Al-i'sar means dust}}
\hadithdefcmd{abudawud}{4175}{حَدَّثَنَا النُّفَيْلِيُّ، وَسَعِيدُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ أَبُو عَلْقَمَةَ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ خُصَيْفَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّمَا امْرَأَةٍ أَصَابَتْ بَخُورًا فَلاَ تَشْهَدَنَّ مَعَنَا الْعِشَاءَ ‏"‏ ‏.‏ قَالَ ابْنُ نُفَيْلٍ ‏"‏ عِشَاءَ الآخِرَةِ ‏"‏ ‏.‏\hadithno{4175}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (444)}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If a woman fumigates herself with perfume, she must not attend the night prayer with us. Ibn Nufayl said: Isha' means night prayer}}
\hadithdefcmd{abudawud}{4176}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَطَاءٌ الْخُرَاسَانِيُّ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، قَالَ قَدِمْتُ عَلَى أَهْلِي لَيْلاً وَقَدْ تَشَقَّقَتْ يَدَاىَ فَخَلَّقُونِي بِزَعْفَرَانٍ فَغَدَوْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ فَلَمْ يَرُدَّ عَلَىَّ وَلَمْ يُرَحِّبْ بِي فَقَالَ ‏"‏ اذْهَبْ فَاغْسِلْ هَذَا عَنْكَ ‏"‏ ‏.‏ فَذَهَبْتُ فَغَسَلْتُهُ ثُمَّ جِئْتُ وَقَدْ بَقِيَ عَلَىَّ مِنْهُ رَدْعٌ فَسَلَّمْتُ فَلَمْ يَرُدَّ عَلَىَّ وَلَمْ يُرَحِّبْ بِي وَقَالَ ‏"‏ اذْهَبْ فَاغْسِلْ هَذَا عَنْكَ ‏"‏ ‏.‏ فَذَهَبْتُ فَغَسَلْتُهُ ثُمَّ جِئْتُ فَسَلَّمْتُ عَلَيْهِ فَرَدَّ عَلَىَّ وَرَحَّبَ بِي وَقَالَ ‏"‏ إِنَّ الْمَلاَئِكَةَ لاَ تَحْضُرُ جَنَازَةَ الْكَافِرِ بِخَيْرٍ وَلاَ الْمُتَضَمِّخَ بِالزَّعْفَرَانِ وَلاَ الْجُنُبَ ‏"‏ ‏.‏ قَالَ وَرَخَّصَ لِلْجُنُبِ إِذَا نَامَ أَوْ أَكَلَ أَوْ شَرِبَ أَنْ يَتَوَضَّأَ ‏.‏\hadithno{4176}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ammar ibn Yasir: I came to my family at night (after a journey) with my hands chapped and they perfumed me with saffron. In the morning I went to the Prophet (ﷺ) and gave him a greeting, but he did not respond to me nor did he welcome me. He said: Go away and wash this off yourself. I then went away and washed it off me. I came to him but there remained a spot of it on me. I give him a greeting, but he did not respond to me nor did he welcome me. He said: Go away and wash it off yourself. I then went away and washed it off me. I then came and gave him a greeting. He responded to me and welcomed me, saying: The angels do not attend the funeral of an unbeliever bringing good to it, nor a man who smears himself with saffron, nor a man who is sexually defiled. He said: He permitted the man who was sexually defiled to perform ablution when he slept, ate or drank}}
\hadithdefcmd{abudawud}{4177}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عُمَرُ بْنُ عَطَاءِ بْنِ أَبِي الْخُوَارِ، أَنَّهُ سَمِعَ يَحْيَى بْنَ يَعْمَرَ، يُخْبِرُ عَنْ رَجُلٍ، أَخْبَرَهُ عَنْ عَمَّارِ بْنِ يَاسِرٍ، - زَعَمَ عُمَرُ أَنَّ يَحْيَى، سَمَّى ذَلِكَ الرَّجُلَ فَنَسِيَ عُمَرُ اسْمَهُ - أَنَّ عَمَّارًا قَالَ تَخَلَّقْتُ بِهَذِهِ الْقِصَّةِ ‏.‏ وَالأَوَّلُ أَتَمُّ بِكَثِيرٍ فِيهِ ذَكَرَ الْغُسْلَ قَالَ قُلْتُ لِعُمَرَ وَهُمْ حُرُمٌ قَالَ لاَ الْقَوْمُ مُقِيمُونَ ‏.‏\hadithno{4177}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above (No. 4164) has also been transmitted by Ammar ibn Yasir through a different chain of narrators. This version has:Ammar said: I used khaluq. The first version is more perfect; it mentioned "taking a bath". Ibn Jurayj said: I said to Umar (a transmitter): They might be wearing ihram (robe of pilgrim)? He replied: No, they were residents}}
\hadithdefcmd{abudawud}{4178}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ الأَسَدِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَرْبٍ الأَسَدِيُّ، حَدَّثَنَا أَبُو جَعْفَرٍ الرَّازِيُّ، عَنِ الرَّبِيعِ بْنِ أَنَسٍ، عَنْ جَدَّيْهِ، قَالاَ سَمِعْنَا أَبَا مُوسَى، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقْبَلُ اللَّهُ تَعَالَى صَلاَةَ رَجُلٍ فِي جَسَدِهِ شَىْءٌ مِنْ خَلُوقٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ جَدَّاهُ زَيْدٌ وَزِيَادٌ ‏.‏\hadithno{4178}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Rabi' b. Anas, quoting his two grandfathers, said:We heard Abu Musa say: The Messenger of Allah (ﷺ) said: Allah does not accept the prayer of a man who has any khaluq (perfume composed of saffron) on his body. Abu Dawud said: His grandfathers were Zaid and Ziyad}}
\hadithdefcmd{abudawud}{4179}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ حَمَّادَ بْنَ زَيْدٍ، وَإِسْمَاعِيلَ بْنَ إِبْرَاهِيمَ، حَدَّثَاهُمْ عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّزَعْفُرِ لِلرِّجَالِ وَقَالَ عَنْ إِسْمَاعِيلَ أَنْ يَتَزَعْفَرَ الرَّجُلُ ‏.‏\hadithno{4179}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2101)}\hadithtrans{Anas said:The Messenger of Allah (ﷺ) forbade men to use saffron. Isma'il version has: "(forbade) man to use saffron}}
\hadithdefcmd{abudawud}{4180}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الأُوَيْسِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنِ الْحَسَنِ بْنِ أَبِي الْحَسَنِ، عَنْ عَمَّارِ بْنِ يَاسِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ لاَ تَقْرَبُهُمُ الْمَلاَئِكَةُ جِيفَةُ الْكَافِرِ وَالْمُتَضَمِّخُ بِالْخَلُوقِ وَالْجُنُبُ إِلاَّ أَنْ يَتَوَضَّأَ ‏"‏ ‏.‏\hadithno{4180}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ammar ibn Yasir: The Prophet (ﷺ) said: The angels do not come near three: the dead body of the unbeliever, one who smears himself with khaluq, and the one who is sexually defiled except that he performs ablution}}
\hadithdefcmd{abudawud}{4181}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، حَدَّثَنَا عُمَرُ بْنُ أَيُّوبَ، عَنْ جَعْفَرِ بْنِ بُرْقَانَ، عَنْ ثَابِتِ بْنِ الْحَجَّاجِ، عَنْ عَبْدِ اللَّهِ الْهَمْدَانِيِّ، عَنِ الْوَلِيدِ بْنِ عُقْبَةَ، قَالَ لَمَّا فَتَحَ نَبِيُّ اللَّهِ صلى الله عليه وسلم مَكَّةَ جَعَلَ أَهْلُ مَكَّةَ يَأْتُونَهُ بِصِبْيَانِهِمْ فَيَدْعُو لَهُمْ بِالْبَرَكَةِ وَيَمْسَحُ رُءُوسَهُمْ قَالَ فَجِيءَ بِي إِلَيْهِ وَأَنَا مُخَلَّقٌ فَلَمْ يَمَسَّنِي مِنْ أَجْلِ الْخَلُوقِ ‏.‏\hadithno{4181}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Walid ibn Uqbah: When the Prophet of Allah (ﷺ) conquered Makkah. The people of Makkah began to bring their boys and he would invoke a blessing on them and rub their heads. I was brought, but as I had been perfumed with khaluq, he did not touch me because of the khaluq}}
\hadithdefcmd{abudawud}{4182}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا سَلْمٌ الْعَلَوِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، دَخَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ أَثَرُ صُفْرَةٍ - وَكَانَ النَّبِيُّ صلى الله عليه وسلم قَلَّمَا يُوَاجِهُ رَجُلاً فِي وَجْهِهِ بِشَىْءٍ يَكْرَهُهُ - فَلَمَّا خَرَجَ قَالَ ‏ "‏ لَوْ أَمَرْتُمْ هَذَا أَنْ يَغْسِلَ هَذَا عَنْهُ ‏"‏ ‏.‏\hadithno{4182}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: A man came to the Messenger of Allah (ﷺ) and he had the mark of yellowness (of saffron). The Prophet (peace be upon him rarely mentioned a thing which he disliked before a man. When he went away, he said: Would that you tell this man that he should wash this off him)}}
\hadithdefcmd{abudawud}{4183}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، وَمُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ مَا رَأَيْتُ مِنْ ذِي لِمَّةٍ أَحْسَنَ فِي حُلَّةٍ حَمْرَاءَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم زَادَ مُحَمَّدُ بْنُ سُلَيْمَانَ لَهُ شَعْرٌ يَضْرِبُ مَنْكِبَيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا رَوَاهُ إِسْرَائِيلُ عَنْ أَبِي إِسْحَاقَ قَالَ يَضْرِبُ مَنْكِبَيْهِ وَقَالَ شُعْبَةُ يَبْلُغُ شَحْمَةَ أُذُنَيْهِ ‏.‏\hadithno{4183}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3551) Sahih Muslim (2337)}\hadithtrans{Narrated Al-Bara' : I did not see any man with locks hanging down to shoulders in red robe more beautiful than the Messenger of Allah (ﷺ). Muhammad b. Sulaiman added: He had hair which touched his shoulders. Abu Dawud said: Isra'il also transmitted it in a similar way from Abu Ishaq saying: "(his hair) touched his shoulders". Shu'bah added: (His hair) reached the lobes of his ears}}
\hadithdefcmd{abudawud}{4184}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَهُ شَعْرٌ يَبْلُغُ شَحْمَةَ أُذُنَيْهِ ‏.‏\hadithno{4184}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Bara' :The Messenger of Allah (ﷺ) had hair which reached the lobes of his ears}}
\hadithdefcmd{abudawud}{4185}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ شَعْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى شَحْمَةِ أُذُنَيْهِ ‏.‏\hadithno{4185}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The hair of the Messenger of Allah (ﷺ) were up to the lobes of his ears}}
\hadithdefcmd{abudawud}{4186}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ شَعْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى أَنْصَافِ أُذُنَيْهِ ‏.‏\hadithno{4186}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2338)}\hadithtrans{Narrated Anas bin Malik:The hair of Messenger of Allah (ﷺ) were halfway down his ears}}
\hadithdefcmd{abudawud}{4187}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ شَعْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَوْقَ الْوَفْرَةِ وَدُونَ الْجُمَّةِ ‏.‏\hadithno{4187}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The hair of the Messenger of Allah (ﷺ) were above wafrah and below jummah}}
\hadithdefcmd{abudawud}{4188}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ أَهْلُ الْكِتَابِ - يَعْنِي - يَسْدِلُونَ أَشْعَارَهُمْ وَكَانَ الْمُشْرِكُونَ يَفْرُقُونَ رُءُوسَهُمْ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم تُعْجِبُهُ مُوَافَقَةُ أَهْلِ الْكِتَابِ فِيمَا لَمْ يُؤْمَرْ بِهِ فَسَدَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاصِيَتَهُ ثُمَّ فَرَقَ بَعْدُ ‏.‏\hadithno{4188}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5917) Sahih Muslim (2336)}\hadithtrans{Narrated Ibn 'Abbas:The people of the Book used to let their hair hand down, and the polytheists used to part their hair. The Messenger of Allah (ﷺ) like to confirm with the People of the Book in the matters about which he had received no command. Hence he Messenger of Allah (ﷺ) let his forelock hang down but afterwards he parted it}}
\hadithdefcmd{abudawud}{4189}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ إِسْحَاقَ - قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كُنْتُ إِذَا أَرَدْتُ أَنْ أَفْرِقَ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَدَعْتُ الْفَرْقَ مِنْ يَافُوخِهِ وَأُرْسِلُ نَاصِيَتَهُ بَيْنَ عَيْنَيْهِ ‏.‏\hadithno{4189}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When I parted the hair of the Messenger of Allah (ﷺ) I made a parting from the crow of his head and let his forelock hang between his eyes}}
\hadithdefcmd{abudawud}{4190}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، وَسُفْيَانُ بْنُ عُقْبَةَ السُّوَائِيُّ، - هُوَ أَخُو قَبِيصَةَ - وَحُمَيْدُ بْنُ خُوَارٍ عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنْ وَائِلِ بْنِ حُجْرٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَلِي شَعْرٌ طَوِيلٌ فَلَمَّا رَآنِي رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ ذُبَابٌ ذُبَابٌ ‏"‏ ‏.‏ قَالَ فَرَجَعْتُ فَجَزَزْتُهُ ثُمَّ أَتَيْتُهُ مِنَ الْغَدِ فَقَالَ ‏"‏ إِنِّي لَمْ أَعْنِكَ وَهَذَا أَحْسَنُ ‏"‏ ‏.‏\hadithno{4190}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Wa'il ibn Hujr: I came to the Prophet (ﷺ) and I had long hair. When the Messenger of Allah (ﷺ) saw me, he said: Evil, evil! He said: I then returned and cut them off. I then came to him in the morning. He said (to me): I did not intend to do evil to you. This is much better}}
\hadithdefcmd{abudawud}{4191}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ قَالَتْ أُمُّ هَانِئٍ قَدِمَ النَّبِيُّ صلى الله عليه وسلم إِلَى مَكَّةَ وَلَهُ أَرْبَعُ غَدَائِرَ تَعْنِي عَقَائِصَ ‏.‏\hadithno{4191}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Hani: The Prophet (ﷺ) came to Mecca and he had four plaits of hair}}
\hadithdefcmd{abudawud}{4192}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، وَابْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ مُحَمَّدَ بْنَ أَبِي يَعْقُوبَ، يُحَدِّثُ عَنِ الْحَسَنِ بْنِ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمْهَلَ آلَ جَعْفَرٍ ثَلاَثًا أَنْ يَأْتِيَهُمْ ثُمَّ أَتَاهُمْ فَقَالَ ‏"‏ لاَ تَبْكُوا عَلَى أَخِي بَعْدَ الْيَوْمِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ ادْعُوا لِي بَنِي أَخِي ‏"‏ ‏.‏ فَجِيءَ بِنَا كَأَنَّا أَفْرُخٌ فَقَالَ ‏"‏ ادْعُوا لِي الْحَلاَّقَ ‏"‏ ‏.‏ فَأَمَرَهُ فَحَلَقَ رُءُوسَنَا ‏.‏\hadithno{4192}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Ja'far: The Prophet (ﷺ) gave the children of Ja'far three day' time to visit them. He then came to visit them, and said: Do not weep over my brother after this day. He said: Call to me the children of my brother. We were brought to him as if we were chicken. He said: Call a barber to me. He then ordered and our heads were shaved}}
\hadithdefcmd{abudawud}{4193}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُثْمَانَ، - قَالَ أَحْمَدُ كَانَ رَجُلاً صَالِحًا - قَالَ أَخْبَرَنَا عُمَرُ بْنُ نَافِعٍ عَنْ أَبِيهِ عَنِ ابْنِ عُمَرَ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْقَزَعِ وَالْقَزَعُ أَنْ يُحْلَقَ رَأْسُ الصَّبِيِّ فَيُتْرَكَ بَعْضُ شَعْرِهِ ‏.‏\hadithno{4193}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5920) Sahih Muslim (2120)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) forbade qaza'. Qaza' means having part of a boy's head shaved and leaving part unshaven}}
\hadithdefcmd{abudawud}{4194}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْقَزَعِ وَهُوَ أَنْ يُحْلَقَ رَأْسُ الصَّبِيِّ فَتُتْرَكَ لَهُ ذُؤَابَةٌ ‏.‏\hadithno{4194}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: the Prophet (ﷺ) forbade qaza' which means that the head of a boy is shaved and a lock is left}}
\hadithdefcmd{abudawud}{4195}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى صَبِيًّا قَدْ حُلِقَ بَعْضُ شَعْرِهِ وَتُرِكَ بَعْضُهُ فَنَهَاهُمْ عَنْ ذَلِكَ وَقَالَ ‏ "‏ احْلِقُوهُ كُلَّهُ أَوِ اتْرُكُوهُ كُلَّهُ ‏"‏ ‏.‏\hadithno{4195}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) saw a boy with part of his head shaved and part left unshaven. He forbade them to do that, saying: Shave it all or leave it all}}
\hadithdefcmd{abudawud}{4196}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مَيْمُونِ بْنِ عَبْدِ اللَّهِ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَتْ لِي ذُؤَابَةٌ فَقَالَتْ لِي أُمِّي لاَ أَجُزُّهَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمُدُّهَا وَيَأْخُذُ بِهَا ‏.‏\hadithno{4196}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: I had a hanging lock of hair. My mother said to me: I shall not cut it, for the Messenger of Allah (ﷺ) used to stretch it our and hold it}}
\hadithdefcmd{abudawud}{4197}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا الْحَجَّاجُ بْنُ حَسَّانَ، قَالَ دَخَلْنَا عَلَى أَنَسِ بْنِ مَالِكٍ فَحَدَّثَتْنِي أُخْتِي الْمُغِيرَةُ، قَالَتْ وَأَنْتَ يَوْمَئِذٍ غُلاَمٌ وَلَكَ قَرْنَانِ أَوْ قُصَّتَانِ فَمَسَحَ رَأْسَكَ وَبَرَّكَ عَلَيْكَ وَقَالَ ‏ "‏ احْلِقُوا هَذَيْنِ أَوْ قُصُّوهُمَا فَإِنَّ هَذَا زِيُّ الْيَهُودِ ‏"‏ ‏.‏\hadithno{4197}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: Al-Hajjaj ibn Hassan said: We entered upon Anas ibn Malik. My sister al-Mughirah said: You were a boy in those days and you had two locks of hair. He (Anas) rubbed your head and invoked blessing on you. He said: Shave them (i.e. the locks) or clip them, for this is the fashion of the Jews}}
\hadithdefcmd{abudawud}{4198}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ الْفِطْرَةُ خَمْسٌ أَوْ خَمْسٌ مِنَ الْفِطْرَةِ الْخِتَانُ وَالاِسْتِحْدَادُ وَنَتْفُ الإِبْطِ وَتَقْلِيمُ الأَظْفَارِ وَقَصُّ الشَّارِبِ ‏"‏ ‏.‏\hadithno{4198}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5889) Sahih Muslim (257)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: The inborn characteristics of man are five. Another version says: Five things are of the inborn characteristics of man: circumcision, shaving the pubes, plucking out hair under the armpit, paring the nails and clipping the moustaches}}
\hadithdefcmd{abudawud}{4199}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِإِحْفَاءِ الشَّوَارِبِ وَإِعْفَاءِ اللِّحَى ‏.‏\hadithno{4199}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5892، 5893) Sahih Muslim (259)}\hadithtrans{Narrated Abd Allah b. 'Umar:The Messenger of Allah (ﷺ) commanded to clip the moustaches and grow the beard long}}
\hadithdefcmd{abudawud}{4200}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا صَدَقَةُ الدَّقِيقِيُّ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ وَقَّتَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَلْقَ الْعَانَةِ وَتَقْلِيمَ الأَظْفَارِ وَقَصَّ الشَّارِبِ وَنَتْفَ الإِبْطِ أَرْبَعِينَ يَوْمًا مَرَّةً ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ جَعْفَرُ بْنُ سُلَيْمَانَ عَنْ أَبِي عِمْرَانَ عَنْ أَنَسٍ لَمْ يَذْكُرِ النَّبِيَّ صلى الله عليه وسلم قَالَ وُقِّتَ لَنَا وَهَذَا أَصَحُّ ‏.‏\hadithno{4200}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik: The Messenger of Allah (ﷺ) fixed forty days to shave the pubes, paring the nails, clipping the moustaches, and plucking the hair under the armpit. Abu Dawud said: Ja'far b. Sulaiman transmitted it from Abu 'Imran on the authority of Anas. In this version he did not mention the Prophet (ﷺ). He said: Forty days were fixed for us. This is a more correct version}}
\hadithdefcmd{abudawud}{4201}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا زُهَيْرٌ، قَرَأْتُ عَلَى عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ وَقَرَأَهُ عَبْدُ الْمَلِكِ عَلَى أَبِي الزُّبَيْرِ وَرَوَاهُ أَبُو الزُّبَيْرِ عَنْ جَابِرٍ، قَالَ كُنَّا نُعْفِي السِّبَالَ إِلاَّ فِي حَجٍّ أَوْ عُمْرَةٍ ‏.‏ قَالَ أَبُو دَاوُدَ الاِسْتِحْدَادُ حَلْقُ الْعَانَةِ ‏.‏\hadithno{4201}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir: We used to grow beard long except during the Hajj or 'Umrah. Abu Dawud said: Istihdad means to shave the pubes}}
\hadithdefcmd{abudawud}{4202}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، - الْمَعْنَى - عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَنْتِفُوا الشَّيْبَ مَا مِنْ مُسْلِمٍ يَشِيبُ شَيْبَةً فِي الإِسْلاَمِ ‏"‏ ‏.‏ قَالَ عَنْ سُفْيَانَ ‏"‏ إِلاَّ كَانَتْ لَهُ نُورًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ يَحْيَى ‏"‏ إِلاَّ كَتَبَ اللَّهُ لَهُ بِهَا حَسَنَةً وَحَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏\hadithno{4202}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr b. Shu'aib, on his father's authority, told that his grandfather reported the Messenger of Allah (ﷺ) said:Do not pluck out grey hair. If any believer grows a grey hair in Islam, he will have light on the Day of Resurrection. (This is Sufyan's version). Yahya's version says: Allah will record on his behalf a good deed for it, and will blot out a sin for it}}
\hadithdefcmd{abudawud}{4203}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، وَسُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْيَهُودَ وَالنَّصَارَى لاَ يَصْبُغُونَ فَخَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{4203}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5899) Sahih Muslim (2103)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: Jews and Christians do not dye (their beards), so act differently from them}}
\hadithdefcmd{abudawud}{4204}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَأَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أُتِيَ بِأَبِي قُحَافَةَ يَوْمَ فَتْحِ مَكَّةَ وَرَأْسُهُ وَلِحْيَتُهُ كَالثَّغَامَةِ بَيَاضًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَيِّرُوا هَذَا بِشَىْءٍ وَاجْتَنِبُوا السَّوَادَ ‏"‏ ‏.‏\hadithno{4204}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2102)}\hadithtrans{Narrated Jabir bin ‘Abdullah :Abu Quhafah was brought on the day of the conquest of Mecca with head and beard while like hyssop. The Messenger of Allah (ﷺ) said: Change this something, but avoid black}}
\hadithdefcmd{abudawud}{4205}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحْسَنَ مَا غُيِّرَ بِهِ هَذَا الشَّيْبُ الْحِنَّاءُ وَالْكَتَمُ ‏"‏ ‏.‏\hadithno{4205}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuDharr: The Prophet (ﷺ) said: The best things with which grey hair are changed are henna and katam}}
\hadithdefcmd{abudawud}{4206}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ إِيَادٍ - قَالَ حَدَّثَنَا إِيَادٌ، عَنْ أَبِي رِمْثَةَ، قَالَ انْطَلَقْتُ مَعَ أَبِي نَحْوَ النَّبِيِّ صلى الله عليه وسلم فَإِذَا هُوَ ذُو وَفْرَةٍ بِهَا رَدْعُ حِنَّاءَ وَعَلَيْهِ بُرْدَانِ أَخْضَرَانِ ‏.‏\hadithno{4206}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuRimthah: I went with my father to the Prophet (ﷺ). He had locks hanging down as far as the lobes of the ears stained with henna, and he was wearing two green garments}}
\hadithdefcmd{abudawud}{4207}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ ابْنَ أَبْجَرَ، عَنْ إِيَادِ بْنِ لَقِيطٍ، عَنْ أَبِي رِمْثَةَ، فِي هَذَا الْخَبَرِ قَالَ فَقَالَ لَهُ أَبِي أَرِنِي هَذَا الَّذِي بِظَهْرِكَ فَإِنِّي رَجُلٌ طَبِيبٌ ‏.‏ قَالَ ‏ "‏ اللَّهُ الطَّبِيبُ بَلْ أَنْتَ رَجُلٌ رَفِيقٌ طَبِيبُهَا الَّذِي خَلَقَهَا ‏"‏ ‏.‏\hadithno{4207}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This version adds (to the previous hadith No 4194):My father said to him (the Prophet): Show me what is on your back, for I am a physician. He (the Prophet) said: You are only a soother. Its physician is He Who has created it}}
\hadithdefcmd{abudawud}{4208}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ إِيَادِ بْنِ لَقِيطٍ، عَنْ أَبِي رِمْثَةَ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم أَنَا وَأَبِي فَقَالَ لِرَجُلٍ أَوْ لأَبِيهِ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ قَالَ ابْنِي ‏.‏ قَالَ ‏"‏ لاَ تَجْنِي عَلَيْهِ ‏"‏ ‏.‏ وَكَانَ قَدْ لَطَخَ لِحْيَتَهُ بِالْحِنَّاءِ ‏.‏\hadithno{4208}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuRimthah: I and my father came to the Prophet (ﷺ). He said to a man or to my father: Who is this? He replied: He is my son. He said: Do not commit a crime on him. He had stained his beard with henna}}
\hadithdefcmd{abudawud}{4209}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّهُ سُئِلَ عَنْ خِضَابِ النَّبِيِّ، صلى الله عليه وسلم فَذَكَرَ أَنَّهُ لَمْ يَخْضِبْ وَلَكِنْ قَدْ خَضَبَ أَبُو بَكْرٍ وَعُمَرُ رَضِيَ اللَّهُ عَنْهُمَا ‏.‏\hadithno{4209}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5895) Sahih Muslim (2341)}\hadithtrans{Thabit said that Anas was asked about the hair-dye of the Prophet (ﷺ). He replied:He did not dye his hair, but Abu Bakr and 'Umar dyed their hair}}
\hadithdefcmd{abudawud}{4210}{حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ مُطَرِّفٍ أَبُو سُفْيَانَ، حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَلْبَسُ النِّعَالَ السِّبْتِيَّةَ وَيُصَفِّرُ لِحْيَتَهُ بِالْوَرْسِ وَالزَّعْفَرَانِ وَكَانَ ابْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{4210}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) used to wear tanned leather sandals and dye his beard yellow with wars and saffron, and Ibn 'Umar used to do that too}}
\hadithdefcmd{abudawud}{4211}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ حُمَيْدِ بْنِ وَهْبٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم رَجُلٌ قَدْ خَضَبَ بِالْحِنَّاءِ فَقَالَ ‏"‏ مَا أَحْسَنَ هَذَا ‏"‏ ‏.‏ قَالَ فَمَرَّ آخَرُ قَدْ خَضَبَ بِالْحِنَّاءِ وَالْكَتَمِ فَقَالَ ‏"‏ هَذَا أَحْسَنُ مِنْ هَذَا ‏"‏ ‏.‏ قَالَ فَمَرَّ آخَرُ قَدْ خَضَبَ بِالصُّفْرَةِ فَقَالَ ‏"‏ هَذَا أَحْسَنُ مِنْ هَذَا كُلِّهِ ‏"‏ ‏.‏\hadithno{4211}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: When a man who had dyed himself with henna passed by the Prophet (ﷺ), he said: How fine this is! When another man who had dyed himself with henna and katam passed by, he said: This is better than that. Then another man who had dyed himself with yellow dye, passed by, he said: This is better than all that}}
\hadithdefcmd{abudawud}{4212}{حَدَّثَنَا أَبُو تَوْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَكُونُ قَوْمٌ يَخْضِبُونَ فِي آخِرِ الزَّمَانِ بِالسَّوَادِ كَحَوَاصِلِ الْحَمَامِ لاَ يَرِيحُونَ رَائِحَةَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{4212}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: At the end of time there will be people who will use this black dye like the crops of doves who will not experience the fragrance of Paradise}}
\hadithdefcmd{abudawud}{4213}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ حُمَيْدٍ الشَّامِيِّ، عَنْ سُلَيْمَانَ الْمَنْبِهِيِّ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَافَرَ كَانَ آخِرُ عَهْدِهِ بِإِنْسَانٍ مِنْ أَهْلِهِ فَاطِمَةَ وَأَوَّلُ مَنْ يَدْخُلُ عَلَيْهَا إِذَا قَدِمَ فَاطِمَةَ فَقَدِمَ مِنْ غَزَاةٍ لَهُ وَقَدْ عَلَّقَتْ مِسْحًا أَوْ سِتْرًا عَلَى بَابِهَا وَحَلَّتِ الْحَسَنَ وَالْحُسَيْنَ قُلْبَيْنِ مِنْ فِضَّةٍ فَقَدِمَ فَلَمْ يَدْخُلْ فَظَنَّتْ أَنَّ مَا مَنَعَهُ أَنْ يَدْخُلَ مَا رَأَى فَهَتَكَتِ السِّتْرَ وَفَكَّكَتِ الْقُلْبَيْنِ عَنِ الصَّبِيَّيْنِ وَقَطَعَتْهُ بَيْنَهُمَا فَانْطَلَقَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُمَا يَبْكِيَانِ فَأَخَذَهُ مِنْهُمَا وَقَالَ ‏"‏ يَا ثَوْبَانُ اذْهَبْ بِهَذَا إِلَى آلِ فُلاَنٍ ‏"‏ ‏.‏ أَهْلِ بَيْتٍ بِالْمَدِينَةِ ‏"‏ إِنَّ هَؤُلاَءِ أَهْلُ بَيْتِي أَكْرَهُ أَنْ يَأْكُلُوا طَيِّبَاتِهِمْ فِي حَيَاتِهِمُ الدُّنْيَا يَا ثَوْبَانُ اشْتَرِ لِفَاطِمَةَ قِلاَدَةً مِنْ عَصَبٍ وَسِوَارَيْنِ مِنْ عَاجٍ ‏"‏ ‏.‏\hadithno{4213}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Thawban: When the Messenger of Allah (ﷺ) went on a journey, the last member of his family he saw was Fatimah, and the first he visited on his return was Fatimah. Once when he returned from an expedition she had hung up a hair-cloth, or a curtain, at her door, and adorned al-Hasan and al-Husayn with silver bracelets. So when he arrived, he did not enter. Thinking that he had been prevented from entering by what he had seen, she tore down the curtain, unfastened the bracelets from the boys and cut them off. They went weeping to the Messenger of Allah (ﷺ), and when he had taken them from them, he said: Take this to so and so's family. Thawban. In Medina, these are my family, and I did not like them to enjoy their good things in the present life. Buy Fatimah a necklace or asb, Thawban, and two ivory bracelets}}
